Class: Tomba::Service
- Inherits:
-
Object
- Object
- Tomba::Service
- Defined in:
- lib/tomba/service.rb
Overview
Base service class.
All Tomba service classes inherit from this base class, which provides access to the API client.
Direct Known Subclasses
Account, Bulk, Count, Domain, Enrichment, Finder, Flag, Format, Keys, Leads, LeadsAttributes, LeadsLists, Location, Logs, Phone, Reveal, Similar, Sources, Status, Technology, Usage, Verifier
Instance Method Summary collapse
-
#initialize(client) ⇒ Service
constructor
Initialize the service with a Tomba client.
Constructor Details
#initialize(client) ⇒ Service
Initialize the service with a Tomba client.
12 13 14 |
# File 'lib/tomba/service.rb', line 12 def initialize(client) @client = client end |