Class: Tomba::Format
Overview
Format service for discovering email formats.
Provides methods to find the email format used by a domain.
Instance Method Summary collapse
-
#email_format(domain) ⇒ Hash
Email Format.
Methods inherited from Service
Constructor Details
This class inherits a constructor from Tomba::Service
Instance Method Details
#email_format(domain) ⇒ Hash
Email Format
Returns the email format used by a given domain (e.g., first.last, first_last).
18 19 20 21 22 23 24 25 26 27 28 |
# File 'lib/tomba/services/format.rb', line 18 def email_format(domain) raise Tomba::Exception, 'Missing required parameter: "domain"' if domain.nil? path = '/email-format' params = { domain: domain } @client.call('get', path, { 'content-type' => 'application/json' }, params) end |