Class: Tomba::Location
- Defined in:
- lib/tomba/services/location.rb
Overview
Location service for retrieving company location data.
Provides methods to get the geographic location associated with a domain.
Instance Method Summary collapse
-
#get_location(domain) ⇒ Hash
Get Location.
Methods inherited from Service
Constructor Details
This class inherits a constructor from Tomba::Service
Instance Method Details
#get_location(domain) ⇒ Hash
Get Location
Returns the geographic location information for a given domain.
18 19 20 21 22 23 24 25 26 27 28 |
# File 'lib/tomba/services/location.rb', line 18 def get_location(domain) raise Tomba::Exception, 'Missing required parameter: "domain"' if domain.nil? path = '/location' params = { domain: domain } @client.call('get', path, { 'content-type' => 'application/json' }, params) end |