Class: Tomba::Sources
Overview
Sources service for finding email sources.
Provides methods to retrieve the sources where an email was found.
Instance Method Summary collapse
-
#email_sources(email:) ⇒ Hash
Email Sources.
Methods inherited from Service
Constructor Details
This class inherits a constructor from Tomba::Service
Instance Method Details
#email_sources(email:) ⇒ Hash
Email Sources
Retrieves the sources where an email address has been found on the web.
18 19 20 21 22 23 24 25 26 27 28 29 |
# File 'lib/tomba/services/sources.rb', line 18 def email_sources(email:) raise Tomba::Exception, 'Missing required parameter: "email"' if email.nil? path = '/email-sources' params = {} params[:email] = email unless email.nil? @client.call('get', path, { 'content-type' => 'application/json' }, params) end |